PlayerSDKViewController class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusHandler ↔ StatusHandler?
getter/setter pair

Methods

close() → Future<void>
handleDoubleTap() → Future<void>
handleMoveContinue(int x, int y) → Future<void>
handleTouchBegin(int x, int y) → Future<void>
handleTouchEnd(int x, int y) → Future<void>
handleZoom(bool isGrow) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(PlayerSDKConfig config, StatusHandler? callbackStatus) → Future<void>
platformCallHandler(MethodCall call) → Future
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited